@@ -9,19 +9,31 @@
 #' @param odir A string of path to the output directory.
 #' @param ... `r rd_dots("alleleCounter")`.
 #' @param alleleCounter `r rd_cmd("alleleCounter")`.
-#' @seealso <https://github.com/cancerit/alleleCount>
+#' @family command
 #' @inherit exec return
+#' @seealso
+#' - <https://github.com/cancerit/alleleCount>
+#'
+#' `r rd_seealso()`
 #' @export
 allele_counter <- make_command(
     "allele_counter",
-    function(hts_file, loci_file,
-             ofile, ..., odir = getwd(),
-             alleleCounter = NULL) {
+    function(
+        hts_file,
+        loci_file,
+        ofile,
+        ...,
+        odir = getwd(),
+        alleleCounter = NULL
+    ) {
         assert_string(alleleCounter, allow_empty = FALSE, allow_null = TRUE)
         AlleleCounter$new(,
-            cmd = alleleCounter, ...,
-            hts_file = hts_file, loci_file = loci_file,
-            ofile = ofile, odir = odir
+            cmd = alleleCounter,
+            ...,
+            hts_file = hts_file,
+            loci_file = loci_file,
+            ofile = ofile,
+            odir = odir
         )
     }
 )
@@ -30,14 +42,14 @@ AlleleCounter <- R6Class(
     "AlleleCounter",
     inherit = Command,
     private = list(
-        name = "alleleCounter",
+        alias = function() "alleleCounter",
         setup_help_params = function() "--help",
         setup_command_params = function(hts_file, loci_file, ofile, odir) {
             opath <- build_opath(odir, ofile)
             c(
-                arg_internal("-l", loci_file),
-                arg_internal("-b", hts_file),
-                arg_internal("-o", opath)
+                arg0("-l", loci_file),
+                arg0("-b", hts_file),
+                arg0("-o", opath)
             )
         }
     )
