@@ -1,15 +1,18 @@
 #' Run cellranger
 #' @param subcmd Sub-Command of cellranger.
-#' @param ... `r rd_dots("cellranger subcmd")`.
+#' @param ... `r rd_dots("cellranger")`.
 #' @param cellranger `r rd_cmd("cellranger")`.
 #' @inherit exec return
+#' @seealso
+#' `r rd_seealso()`
+#' @family command
 #' @export
 cellranger <- make_command(
     "cellranger",
     function(subcmd = NULL, ..., cellranger = NULL) {
         assert_string(subcmd, allow_empty = FALSE, allow_null = TRUE)
         assert_string(cellranger, allow_empty = FALSE, allow_null = TRUE)
-        CellRanger$new(cmd = cellranger, ..., .subcmd = subcmd)
+        CellRanger$new(cmd = cellranger, ..., subcmd = subcmd)
     }
 )
 
@@ -17,7 +20,10 @@ CellRanger <- R6Class(
     "CellRanger",
     inherit = Command,
     private = list(
-        name = "cellranger",
-        setup_help_params = function() "--help"
+        alias = function() "cellranger",
+        setup_help_params = function() "--help",
+        combine_params = function(subcmd) {
+            c(subcmd, super$combine_params())
+        }
     )
 )
