@@ -8,8 +8,12 @@
 #' `r oxford_comma(code_quote(KrakenToolsScripts))`.
 #' @param ... `r rd_dots("kraken_tools")`.
 #' @inheritParams python
-#' @seealso <https://github.com/jenniferlu717/KrakenTools>
+#' @seealso 
+#' - <https://github.com/jenniferlu717/KrakenTools>
+#' 
+#' `r rd_seealso()`
 #' @inherit exec return
+#' @family command
 #' @export
 kraken_tools <- make_command(
     "kraken_tools",
@@ -24,10 +28,8 @@ KrakenTools <- R6Class(
     inherit = Python,
     private = list(
         combine_params = function(script) {
-            script <- internal_file("KrakenTools", paste0(script, ".py"))
-            if (file.access(script, mode = 1L) != 0L) {
-                Sys.chmod(script, "555")
-            }
+            script <- pkg_extdata("KrakenTools", paste0(script, ".py"))
+            file_executable(script)
             c(script, super$combine_params())
         }
     )
