@@ -3,8 +3,12 @@
 #'
 #' @param ... `r rd_dots("perl")`.
 #' @param perl `r rd_cmd("perl")`.
-#' @seealso <https://www.perl.org/>
+#' @seealso
+#' - <https://www.perl.org/>
+#'
+#' `r rd_seealso()`
 #' @inherit exec return
+#' @family command
 #' @export
 perl <- make_command(
     "perl",
@@ -18,7 +22,7 @@ Perl <- R6Class(
     "Perl",
     inherit = Command,
     private = list(
-        name = "perl",
+        alias = function() "perl",
         setup_help_params = function() "--help"
     )
 )
