@@ -3,8 +3,12 @@
 #'
 #' @param ... `r rd_dots("python")`.
 #' @param python `r rd_cmd("python")`.
-#' @seealso <https://www.python.org/>
+#' @seealso
+#' - <https://www.python.org/>
+#'
+#' `r rd_seealso()`
 #' @inherit exec return
+#' @family command
 #' @export
 python <- make_command(
     "python",
@@ -18,8 +22,7 @@ Python <- R6Class(
     "Python",
     inherit = Command,
     private = list(
-        name = "python",
-        alias = c("python3", "python2"),
+        alias = function() c("python", "python3", "python2"),
         setup_help_params = function() "--help"
     )
 )
