@@ -2,8 +2,12 @@
 #' @param subcmd Sub-Command of seqkit.
 #' @param ... `r rd_dots("seqkit subcmd")`.
 #' @param seqkit `r rd_cmd("seqkit")`.
-#' @seealso <https://bioinf.shenwei.me/seqkit/>
+#' @seealso
+#' - <https://bioinf.shenwei.me/seqkit/>
+#'
+#' `r rd_seealso()`
 #' @inherit exec return
+#' @family command
 #' @export
 seqkit <- make_command(
     "seqkit",
@@ -18,7 +22,7 @@ SeqKit <- R6Class(
     "SeqKit",
     inherit = Command,
     private = list(
-        name = "seqkit",
+        alias = function() "seqkit",
         setup_help_params = function() "--help"
     )
 )
